import type { OperationPlan } from "../index.js";
import type { ExecutableStep } from "../step";
import type { LayerPlan, LayerPlanReasonsWithParentStep } from "./LayerPlan";
import type { OutputPlan } from "./OutputPlan";
/**
 * This class keeps track of all of our steps, and the dependencies between
 * steps and other steps, layer plans and steps, and output plans and steps.
 *
 * When a step is replaced by another step, all the dependencies are updated
 * such that the replaced step simply evaporates.
 *
 * @internal
 */
export declare class StepTracker {
    private readonly operationPlan;
    /** @internal */
    stepCount: number;
    /** @internal */
    activeSteps: Set<ExecutableStep<any>>;
    /** @internal */
    stepById: {
        [stepId: number]: ExecutableStep | null;
    };
    /** @internal */
    private aliasesById;
    /** @internal */
    stepsWithNoDependencies: Set<ExecutableStep<any>>;
    /** @internal */
    outputPlansByRootStep: Map<ExecutableStep<any>, Set<OutputPlan<import("./OutputPlan").OutputPlanType>>>;
    /** @internal */
    layerPlansByRootStep: Map<ExecutableStep<any>, Set<LayerPlan<import("./LayerPlan").LayerPlanReason>>>;
    /** @internal */
    layerPlansByParentStep: Map<ExecutableStep<any>, Set<LayerPlan<LayerPlanReasonsWithParentStep>>>;
    /** @internal */
    layerPlans: Array<LayerPlan | null>;
    /**
     * All the OutputPlans that were created to allow a more efficient
     * walkOutputPlans implementation.
     *
     * @internal
     */
    allOutputPlans: OutputPlan[];
    nextStepIdToDeduplicate: number;
    constructor(operationPlan: OperationPlan);
    newStepsSince(oldStepCount: number): ExecutableStep<any>[];
    private forbid;
    /** Called when OperationPlan enters finalize phase. */
    finalizeSteps(): void;
    /** Called when OperationPlan is about to finalize the output plans. */
    finalizeOutputPlans(): void;
    addStep($step: ExecutableStep): number;
    /**
     * @internal
     */
    addLayerPlan(layerPlan: LayerPlan): number;
    /**
     * @internal
     */
    addOutputPlan(outputPlan: OutputPlan): void;
    /**
     * HIGHLY EXPERIMENTAL!
     *
     * @internal
     */
    deleteLayerPlan(layerPlan: LayerPlan): void;
    getStepById(id: number): ExecutableStep;
    getStepById(id: number, allowUnset: true): ExecutableStep | null;
    addStepDependency($dependent: ExecutableStep, $dependency: ExecutableStep): number;
    setOutputPlanRootStep(outputPlan: OutputPlan, $dependency: ExecutableStep): void;
    setLayerPlanRootStep(layerPlan: LayerPlan, $dependency: ExecutableStep): void;
    /** @internal */
    replaceStep($original: ExecutableStep, $replacement: ExecutableStep): void;
    treeShakeSteps(): void;
    /**
     * Return true if this step can be tree-shaken.
     */
    private isNotNeeded;
    /**
     * Only for use during planField.
     */
    purgeBackTo(count: number): void;
    /**
     * ONLY CALL THIS IF NOTHING DEPENDS ON $original! It's intended to be called
     * from `replaceStep` or from itself.
     *
     * This method removes $original from the various maps/sets/lists, and also
     * removes the fact that it was dependent on other steps. If these other
     * steps no longer have any dependents (steps, layer plans or output plans)
     * then they can also be eradicated _except_ during the 'plan' phase.
     */
    private eradicate;
    moveStepToLayerPlan(step: ExecutableStep, targetLayerPlan: LayerPlan): void;
    addStepToItsLayerPlan(step: ExecutableStep): void;
    removeStepFromItsLayerPlan(step: ExecutableStep): void;
}
//# sourceMappingURL=StepTracker.d.ts.map