/// <reference types="node" />
import type { $$extensions } from "./interfaces.js";
import { $$safeError } from "./interfaces.js";
/**
 * Internally we wrap errors that occur in a GrafastError; this allows us to do
 * simple `instanceof` checks to see if a value is an actual value or an error.
 * Users should never use this class; it's for internal usage only.
 *
 * @internal
 */
export interface GrafastError extends Error {
    originalError: Error;
    [$$extensions]?: Record<string, any>;
}
export declare const $$error: unique symbol;
/**
 * When an error occurs during plan execution we wrap it in a GrafastError so
 * that we can pass it around as a value.  It gets unwrapped and thrown in the
 * grafast resolver.
 *
 * @internal
 */
export declare const _GrafastError: {
    new (originalError: Error, planId: number | null): {
        readonly originalError: Error;
        extensions: Record<string, any>;
        [$$error]: boolean;
        name: string;
        message: string;
        stack?: string | undefined;
        cause?: unknown;
    };
    captureStackTrace(targetObject: object, constructorOpt?: Function | undefined): void;
    prepareStackTrace?: ((err: Error, stackTraces: NodeJS.CallSite[]) => any) | undefined;
    stackTraceLimit: number;
};
/**
 * DO NOT ALLOW CONSTRUCTION OF ERRORS OUTSIDE OF THIS MODULE!
 *
 * @internal
 */
export declare function newGrafastError(error: Error, planId: number | null): {
    readonly originalError: Error;
    extensions: Record<string, any>;
    [$$error]: boolean;
    name: string;
    message: string;
    stack?: string | undefined;
    cause?: unknown;
};
/**
 * Is the given value a GrafastError? This is the only public API that people
 * should use for looking at GrafastErrors.
 */
export declare function isGrafastError(value: any): value is GrafastError;
export declare class SafeError<TExtensions extends Record<string, any> | undefined = Record<string, any> | undefined> extends Error {
    extensions: TExtensions;
    [$$safeError]: boolean;
    constructor(message: string, extensions?: TExtensions, errorOptions?: ErrorOptions);
}
export declare function isSafeError(error: Error): error is SafeError;
//# sourceMappingURL=error.d.ts.map