import type { OperationPlan } from ".";
import type { ExecutableStep } from "./step.js";
/**
 * An array of hex colour codes that we use for colouring the buckets/steps in
 * the mermaid-js plan diagram.
 *
 * Generated by mokole.com/palette.html; re-ordered by Jem
 */
export declare const COLORS: string[];
/**
 * Given a string, escapes the string so that it can be embedded as the description of a node in a mermaid chart.
 *
 * 1. If it's already safe, returns it verbatim
 * 2. If it contains disallowed characters, escape them by replacing them with similar-looking characters,
 * 3. Wrap the string in quote marks.
 *
 * @remarks
 *
 * NOTE: rather than doing literal escapes, we replace with lookalike characters because:
 *
 * 1. Mermaid has a bug when calculating the width of the node that doesn't respect escapes,
 * 2. It's easier to read the raw mermaid markup with substitutes rather than messy escapes.
 *
 * @internal
 */
export declare const mermaidEscape: (str: string) => string;
export interface PrintPlanGraphOptions {
    printPathRelations?: boolean;
    includePaths?: boolean;
    concise?: boolean;
    skipBuckets?: boolean;
}
/**
 * Convert an OpPlan into a plan graph; call this via `operationPlan.printPlanGraph()`
 * rather than calling this function directly.
 *
 * @internal
 */
export declare function printPlanGraph(operationPlan: OperationPlan, { concise, skipBuckets, }: PrintPlanGraphOptions, { steps, }: {
    steps: {
        [stepId: number]: ExecutableStep | null;
    };
}): string;
//# sourceMappingURL=mermaid.d.ts.map