import type { ExecutionExtra } from "../interfaces.js";
import type { ExecutableStep } from "../step.js";
import { UnbatchedExecutableStep } from "../step.js";
/** @internal */
export declare const expressionSymbol: unique symbol;
/**
 * Accesses a (potentially nested) property from the result of a plan.
 *
 * NOTE: this could lead to unexpected results (which could introduce security
 * issues) if it is not used carefully; only use it on JSON-like data,
 * preferably where the objects have null prototypes, and be sure to adhere to
 * the naming conventions detailed in assertSafeToAccessViaBraces.
 */
export declare class AccessStep<TData> extends UnbatchedExecutableStep<TData> {
    readonly fallback?: any;
    static $$export: {
        moduleName: string;
        exportName: string;
    };
    isSyncAndSafe: boolean;
    allowMultipleOptimizations: boolean;
    readonly path: (string | number | symbol)[];
    constructor(parentPlan: ExecutableStep<unknown>, path: (string | number | symbol)[], fallback?: any);
    toStringMeta(): string;
    /**
     * Get the named property of an object.
     */
    get<TAttr extends keyof TData>(attrName: TAttr): AccessStep<TData[TAttr]>;
    /**
     * Get the entry at the given index in an array.
     */
    at<TIndex extends keyof TData>(index: TIndex): AccessStep<TData[TIndex]>;
    optimize(): AccessStep<TData>;
    finalize(): void;
    unbatchedExecute(_extra: ExecutionExtra, ..._values: any[]): any;
    deduplicate(peers: AccessStep<unknown>[]): AccessStep<TData>[];
}
/**
 * Access the property at path `path` in the value returned from `parentPlan`,
 * falling back to `fallback` if it were null-ish.
 */
export declare function access<TData>(parentPlan: ExecutableStep<unknown>, path: (string | number | symbol)[] | string | number | symbol, fallback?: any): AccessStep<TData>;
//# sourceMappingURL=access.d.ts.map